@@ -7,7 +7,7 @@ TwoStageSurvSurv <- function(Dataset, Surr, SurrCens, True, TrueCens, Treat,
   TrueCens <- Dataset[,paste(substitute(TrueCens))]
   Treat <- Dataset[,paste(substitute(Treat))]
   Trial.ID <- Dataset[,paste(substitute(Trial.ID))]
-  All_data <- data.frame(cbind(Surr, SurrCens, True, TrueCens, Treat, Trial.ID))
+  All_data <- data.frame(cbind(Surr, SurrCens, True, TrueCens, Treat, Trial.ID), stringsAsFactors = TRUE)
   names(All_data) <- c("Surr", "SurrCens", "True", "TrueCens", "Treat", "Trial.ID")
   
   Results.Stage.1 <- Data.Analyze <- NULL
@@ -31,7 +31,7 @@ TwoStageSurvSurv <- function(Dataset, Surr, SurrCens, True, TrueCens, Treat,
       Data.Analyze <- rbind(Data.Analyze, Data_hier)
     }
   }
-  Results.Stage.1 <- data.frame(Results.Stage.1)
+  Results.Stage.1 <- data.frame(Results.Stage.1, stringsAsFactors = TRUE)
   
   # stage 2
   if (Weighted==FALSE){
@@ -48,7 +48,7 @@ Trial.R2.value <- as.numeric(summary(Results.Stage.2)[c("r.squared")])
   Trial.R2.sd <- sqrt((4*Trial.R2.value*(1-Trial.R2.value)^2)/(N.trial-3))
   Trial.R2.lb <- max(0, Trial.R2.value + qnorm(Alpha/2) *(Trial.R2.sd))
   Trial.R2.ub <- min(1, Trial.R2.value + qnorm(1-Alpha/2)*(Trial.R2.sd))
-  Trial.R2 <- data.frame(cbind(Trial.R2.value, Trial.R2.sd, Trial.R2.lb, Trial.R2.ub))
+  Trial.R2 <- data.frame(cbind(Trial.R2.value, Trial.R2.sd, Trial.R2.lb, Trial.R2.ub), stringsAsFactors = TRUE)
   colnames(Trial.R2) <- c("R2.ht", "Standard Error", "CI lower limit", "CI upper limit")
   rownames(Trial.R2) <- c(" ") 
   
@@ -58,7 +58,7 @@ Trial.R2.value <- as.numeric(summary(Results.Stage.2)[c("r.squared")])
   Trial.R.lb <- max(0, (exp(2*(Z-(qnorm(1-Alpha/2)*sqrt(1/(N.trial-3)))))-1)/(exp(2*(Z-(qnorm(1-Alpha/2)*sqrt(1/(N.trial-3)))))+1))
   Trial.R.ub <- min(1, (exp(2*(Z+(qnorm(1-Alpha/2)*sqrt(1/(N.trial-3)))))-1)/(exp(2*(Z+(qnorm(1-Alpha/2)*sqrt(1/(N.trial-3)))))+1))
   Trial.R.sd <- sqrt((1-Trial.R.value**2)/(N.trial-2))
-  Trial.R <- data.frame(cbind(Trial.R.value, Trial.R.sd , Trial.R.lb, Trial.R.ub))
+  Trial.R <- data.frame(cbind(Trial.R.value, Trial.R.sd , Trial.R.lb, Trial.R.ub), stringsAsFactors = TRUE)
   colnames(Trial.R) <- c("R.ht", "Standard Error", "CI lower limit", "CI upper limit")
   row.names(Trial.R) <- c(" ") 
   
